"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeEmissionDistributorIx = exports.distributeEmissionsIx = exports.manualMintIx = exports.updateEmissionScheduleIx = exports.updateEmissionDistributorIx = exports.updateEmissionScheduleReceiptV0Ix = void 0;
const index_1 = require("./index");
const bn_js_1 = __importDefault(require("bn.js"));
const circuit_breaker_sdk_1 = require("@render-foundation/circuit-breaker-sdk");
const spl_utils_1 = require("@render-foundation/spl-utils");
const updateEmissionScheduleReceiptV0Ix = (program, epochId, rndrMint, authority, args) => {
    let { totalMinted, totalBurnRewardsMinted, totalUpgradeRewardsMinted, epochStartedAt, epochEndedAt, } = args;
    return program.methods
        .updateEmissionScheduleReceiptV0({
        totalMinted: totalMinted ? new bn_js_1.default(totalMinted) : null,
        totalBurnRewardsMinted: totalBurnRewardsMinted ? new bn_js_1.default(totalBurnRewardsMinted) : null,
        totalUpgradeRewardsMinted: totalUpgradeRewardsMinted ? new bn_js_1.default(totalUpgradeRewardsMinted) : null,
        epochStartedAt: epochStartedAt ? new bn_js_1.default(epochStartedAt) : null,
        epochEndedAt: epochEndedAt ? new bn_js_1.default(epochEndedAt) : null,
    })
        .accounts({
        emissionScheduleReceipt: (0, index_1.emissionScheduleReceiptKey)(rndrMint, epochId)[0],
        rndrMint,
        authority,
    }).instruction();
};
exports.updateEmissionScheduleReceiptV0Ix = updateEmissionScheduleReceiptV0Ix;
const updateEmissionDistributorIx = (program, rndrMint, args, accts) => {
    var _a, _b, _c, _d, _e;
    return program
        .methods
        .updateEmissionDistributorV0({
        distributionEscrows: (_a = args.distributionEscrows) !== null && _a !== void 0 ? _a : null,
        emissionSchedule: (_b = args.emissionSchedule) !== null && _b !== void 0 ? _b : null,
        manualMintAuthority: (_c = args.manualMintAuthority) !== null && _c !== void 0 ? _c : null,
        authority: (_d = args.authority) !== null && _d !== void 0 ? _d : null,
    })
        .accounts({
        rndrMint,
        emissionDistributor: (0, index_1.emissionDistributorKey)(rndrMint, program.programId)[0],
        payer: (_e = accts.payer) !== null && _e !== void 0 ? _e : accts.authority,
        authority: accts.authority
    }).instruction();
};
exports.updateEmissionDistributorIx = updateEmissionDistributorIx;
const updateEmissionScheduleIx = (program, rndrMint, args, accts) => {
    return program
        .methods
        .updateEmissionScheduleV0({
        emissionSchedule: !!args.emissionSchedule && args.emissionSchedule.length > 0 ? args.emissionSchedule.map(({ startUnixTime, emissionsPerEpoch }) => ({
            startUnixTime: new bn_js_1.default(startUnixTime),
            emissionsPerEpoch: new bn_js_1.default(emissionsPerEpoch)
        })) : null,
        epochDurationSecs: args.epochDurationSecs ? new bn_js_1.default(args.epochDurationSecs) : null,
        currentEpochBeganAt: args.currentEpochBeganAt ? new bn_js_1.default(args.currentEpochBeganAt) : null,
    })
        .accounts({
        authority: accts.authority,
        schedule: (0, index_1.emissionScheduleKey)(rndrMint, program.programId)[0]
    }).instruction();
};
exports.updateEmissionScheduleIx = updateEmissionScheduleIx;
const manualMintIx = (program, rndrMint, recipientAta, authority, amount, circuitBreakerProgram = circuit_breaker_sdk_1.PROGRAM_ID) => {
    return program.methods.manualMintV0({ amount: (0, spl_utils_1.toBN)(amount, rndrMint.decimals) })
        .accounts({
        //circuitBreaker: circuitBreakerK,
        //payer: authority,
        authority,
        recipientAta,
        rndrMint: rndrMint.address,
        emissionDistributor: (0, index_1.emissionDistributorKey)(rndrMint.address, program.programId)[0],
        circuitBreakerProgram
    }).instruction();
};
exports.manualMintIx = manualMintIx;
const distributeEmissionsIx = (program, rndrMint, escrows, accts, circuitBreakerProgram = circuit_breaker_sdk_1.PROGRAM_ID) => {
    var _a;
    console.log(`singerfoo ${(_a = accts === null || accts === void 0 ? void 0 : accts.payer) === null || _a === void 0 ? void 0 : _a.toString()}`);
    return program.methods
        .distributeEmissionsV0()
        .accounts({
        emissionDistributor: (0, index_1.emissionDistributorKey)(rndrMint, program.programId)[0],
        emissionSchedule: (0, index_1.emissionScheduleKey)(rndrMint, program.programId)[0],
        rndrMint: rndrMint,
        payer: accts === null || accts === void 0 ? void 0 : accts.payer
        //circuitBreakerProgram
    })
        .remainingAccounts(escrows.map((a) => ({ pubkey: a, isSigner: false, isWritable: true })))
        .instruction();
};
exports.distributeEmissionsIx = distributeEmissionsIx;
const initializeEmissionDistributorIx = (program, rndrMint, args, circuitBreakerProgram = circuit_breaker_sdk_1.PROGRAM_ID) => {
    var _a, _b;
    return program
        .methods
        .initializeEmissionDistributorV0({
        authority: args.authority,
        manualEmissionAuthority: (_a = args.manualEmissionAuthority) !== null && _a !== void 0 ? _a : args.authority,
        distributionAccounts: args.distributionAccounts,
        epochDurationSec: new bn_js_1.default(args.epochDurationSec),
        emissionSchedule: args.schedule.map(i => ({ startUnixTime: new bn_js_1.default(i.startUnixTime),
            emissionsPerEpoch: (0, spl_utils_1.toBN)(i.emissionsPerEpoch, rndrMint.decimals) })),
        mintCircuitBreakerConfig: args.mintCircuitBreakerConfig,
        currentEpochBeganAt: new bn_js_1.default(args.currentEpochBeganAt)
    }).
        accounts({
        payer: (_b = args.payer) !== null && _b !== void 0 ? _b : rndrMint.mintAuthority,
        mintAuthority: rndrMint.mintAuthority,
        freezeAuthority: rndrMint.freezeAuthority,
        //circuitBreaker: mintWindowedBreakerKey(rndrMint.address)[0],
        emissionDistributor: (0, index_1.emissionDistributorKey)(rndrMint.address, program.programId)[0],
        emissionSchedule: (0, index_1.emissionScheduleKey)(rndrMint.address, program.programId)[0],
        rndrMint: rndrMint.address,
        circuitBreakerProgram
    }).instruction();
};
exports.initializeEmissionDistributorIx = initializeEmissionDistributorIx;
//# sourceMappingURL=instructions.js.map