"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.emissionDistributorResolvers = exports.emissionScheduleReceiptResolver = void 0;
const spl_utils_1 = require("@render-foundation/spl-utils");
const circuit_breaker_sdk_1 = require("@render-foundation/circuit-breaker-sdk");
const index_1 = require("./index");
const pdas_1 = require("./pdas");
const emissionScheduleReceiptResolver = (kind, ixNames = []) => {
    return (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, programId, args }) => __awaiter(void 0, void 0, void 0, function* () {
        if ((ixNames.length > 0 ? true : ixNames.includes(idlIx.name)) && path[path.length - 1] === "emissionScheduleReceipt") {
            const program = yield (0, index_1.init)(provider, index_1.PROGRAM_ID, true);
            const emissionScheduleK = (0, spl_utils_1.get)(accounts, [
                ...path.slice(0, path.length - 1),
                "emissionSchedule",
            ]);
            const rndrMintK = (0, spl_utils_1.get)(accounts, [
                ...path.slice(0, path.length - 1),
                "rndrMint",
            ]);
            const emissionSchedule = yield program.account.emissionScheduleV0.fetch(emissionScheduleK);
            return (0, pdas_1.emissionScheduleReceiptKey)(rndrMintK, kind == 'prevEpoch' ? emissionSchedule.epochId.toNumber() - 1 : emissionSchedule.epochId.toNumber(), programId)[0];
        }
    }));
};
exports.emissionScheduleReceiptResolver = emissionScheduleReceiptResolver;
exports.emissionDistributorResolvers = (0, spl_utils_1.combineResolvers)(spl_utils_1.renderCommonResolver, circuit_breaker_sdk_1.circuitBreakerResolvers, 
/*ataResolver({
  instruction: "manualMintV0",
  account: "recipientAta",
  mint: "rndrMint",
  owner: "recipient"
}),*/
(0, exports.emissionScheduleReceiptResolver)('currEpoch', ['distributeEmissionsV0', 'updateEmissionScheduleReceiptV0']), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "circuitBreaker") {
        const circuitBreakerPid = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "circuitBreakerProgram",
        ]);
        const rndrMintK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        return (0, circuit_breaker_sdk_1.mintWindowedBreakerKey)(rndrMintK, circuitBreakerPid)[0];
    }
})));
//# sourceMappingURL=resolvers.js.map