import { emissionDistributorKey, emissionScheduleKey, emissionScheduleReceiptKey } from "./index";
import BN from "bn.js";
import { PROGRAM_ID as CIRCUIT_BREAKER_PROGRAM_ID } from "@render-foundation/circuit-breaker-sdk";
import { toBN } from "@render-foundation/spl-utils";
export const updateEmissionScheduleReceiptV0Ix = (program, epochId, rndrMint, authority, args) => {
    let { totalMinted, totalBurnRewardsMinted, totalUpgradeRewardsMinted, epochStartedAt, epochEndedAt, } = args;
    return program.methods
        .updateEmissionScheduleReceiptV0({
        totalMinted: totalMinted ? new BN(totalMinted) : null,
        totalBurnRewardsMinted: totalBurnRewardsMinted ? new BN(totalBurnRewardsMinted) : null,
        totalUpgradeRewardsMinted: totalUpgradeRewardsMinted ? new BN(totalUpgradeRewardsMinted) : null,
        epochStartedAt: epochStartedAt ? new BN(epochStartedAt) : null,
        epochEndedAt: epochEndedAt ? new BN(epochEndedAt) : null,
    })
        .accounts({
        emissionScheduleReceipt: emissionScheduleReceiptKey(rndrMint, epochId)[0],
        rndrMint,
        authority,
    }).instruction();
};
export const updateEmissionDistributorIx = (program, rndrMint, args, accts) => {
    return program
        .methods
        .updateEmissionDistributorV0({
        distributionEscrows: args.distributionEscrows ?? null,
        emissionSchedule: args.emissionSchedule ?? null,
        manualMintAuthority: args.manualMintAuthority ?? null,
        authority: args.authority ?? null,
    })
        .accounts({
        rndrMint,
        emissionDistributor: emissionDistributorKey(rndrMint, program.programId)[0],
        payer: accts.payer ?? accts.authority,
        authority: accts.authority
    }).instruction();
};
export const updateEmissionScheduleIx = (program, rndrMint, args, accts) => {
    return program
        .methods
        .updateEmissionScheduleV0({
        emissionSchedule: !!args.emissionSchedule && args.emissionSchedule.length > 0 ? args.emissionSchedule.map(({ startUnixTime, emissionsPerEpoch }) => ({
            startUnixTime: new BN(startUnixTime),
            emissionsPerEpoch: new BN(emissionsPerEpoch)
        })) : null,
        epochDurationSecs: args.epochDurationSecs ? new BN(args.epochDurationSecs) : null,
        currentEpochBeganAt: args.currentEpochBeganAt ? new BN(args.currentEpochBeganAt) : null,
    })
        .accounts({
        authority: accts.authority,
        schedule: emissionScheduleKey(rndrMint, program.programId)[0]
    }).instruction();
};
export const manualMintIx = (program, rndrMint, recipientAta, authority, amount, circuitBreakerProgram = CIRCUIT_BREAKER_PROGRAM_ID) => {
    return program.methods.manualMintV0({ amount: toBN(amount, rndrMint.decimals) })
        .accounts({
        //circuitBreaker: circuitBreakerK,
        //payer: authority,
        authority,
        recipientAta,
        rndrMint: rndrMint.address,
        emissionDistributor: emissionDistributorKey(rndrMint.address, program.programId)[0],
        circuitBreakerProgram
    }).instruction();
};
export const distributeEmissionsIx = (program, rndrMint, escrows, accts, circuitBreakerProgram = CIRCUIT_BREAKER_PROGRAM_ID) => {
    console.log(`singerfoo ${accts?.payer?.toString()}`);
    return program.methods
        .distributeEmissionsV0()
        .accounts({
        emissionDistributor: emissionDistributorKey(rndrMint, program.programId)[0],
        emissionSchedule: emissionScheduleKey(rndrMint, program.programId)[0],
        rndrMint: rndrMint,
        payer: accts?.payer
        //circuitBreakerProgram
    })
        .remainingAccounts(escrows.map((a) => ({ pubkey: a, isSigner: false, isWritable: true })))
        .instruction();
};
export const initializeEmissionDistributorIx = (program, rndrMint, args, circuitBreakerProgram = CIRCUIT_BREAKER_PROGRAM_ID) => {
    return program
        .methods
        .initializeEmissionDistributorV0({
        authority: args.authority,
        manualEmissionAuthority: args.manualEmissionAuthority ?? args.authority,
        distributionAccounts: args.distributionAccounts,
        epochDurationSec: new BN(args.epochDurationSec),
        emissionSchedule: args.schedule.map(i => ({ startUnixTime: new BN(i.startUnixTime),
            emissionsPerEpoch: toBN(i.emissionsPerEpoch, rndrMint.decimals) })),
        mintCircuitBreakerConfig: args.mintCircuitBreakerConfig,
        currentEpochBeganAt: new BN(args.currentEpochBeganAt)
    }).
        accounts({
        payer: args.payer ?? rndrMint.mintAuthority,
        mintAuthority: rndrMint.mintAuthority,
        freezeAuthority: rndrMint.freezeAuthority,
        //circuitBreaker: mintWindowedBreakerKey(rndrMint.address)[0],
        emissionDistributor: emissionDistributorKey(rndrMint.address, program.programId)[0],
        emissionSchedule: emissionScheduleKey(rndrMint.address, program.programId)[0],
        rndrMint: rndrMint.address,
        circuitBreakerProgram
    }).instruction();
};
//# sourceMappingURL=instructions.js.map