import { combineResolvers, get, renderCommonResolver, resolveIndividual } from "@render-foundation/spl-utils";
import { circuitBreakerResolvers, mintWindowedBreakerKey } from "@render-foundation/circuit-breaker-sdk";
import { init, PROGRAM_ID } from "./index";
import { emissionScheduleReceiptKey } from "./pdas";
export const emissionScheduleReceiptResolver = (kind, ixNames = []) => {
    return resolveIndividual(async ({ path, accounts, idlIx, provider, programId, args }) => {
        if ((ixNames.length > 0 ? true : ixNames.includes(idlIx.name)) && path[path.length - 1] === "emissionScheduleReceipt") {
            const program = await init(provider, PROGRAM_ID, true);
            const emissionScheduleK = get(accounts, [
                ...path.slice(0, path.length - 1),
                "emissionSchedule",
            ]);
            const rndrMintK = get(accounts, [
                ...path.slice(0, path.length - 1),
                "rndrMint",
            ]);
            const emissionSchedule = await program.account.emissionScheduleV0.fetch(emissionScheduleK);
            return emissionScheduleReceiptKey(rndrMintK, kind == 'prevEpoch' ? emissionSchedule.epochId.toNumber() - 1 : emissionSchedule.epochId.toNumber(), programId)[0];
        }
    });
};
export const emissionDistributorResolvers = combineResolvers(renderCommonResolver, circuitBreakerResolvers, 
/*ataResolver({
  instruction: "manualMintV0",
  account: "recipientAta",
  mint: "rndrMint",
  owner: "recipient"
}),*/
emissionScheduleReceiptResolver('currEpoch', ['distributeEmissionsV0', 'updateEmissionScheduleReceiptV0']), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === "circuitBreaker") {
        const circuitBreakerPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            "circuitBreakerProgram",
        ]);
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        return mintWindowedBreakerKey(rndrMintK, circuitBreakerPid)[0];
    }
}));
//# sourceMappingURL=resolvers.js.map